<?php

namespace Annie\Causes\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Causes\Models\CauseKindSupport;

class CauseKindSupportPolicy
{

    /**
     * Determine if the given user can view the cause_kind_support.
     *
     * @param UserPolicy $user
     * @param CauseKindSupport $cause_kind_support
     *
     * @return bool
     */
    public function view(UserPolicy $user, CauseKindSupport $cause_kind_support)
    {
        if ($user->canDo('causes.cause_kind_support.view') && $user->isAdmin()) {
            return true;
        }

        return $cause_kind_support->user_id == user_id() && $cause_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cause_kind_support.
     *
     * @param UserPolicy $user
     * @param CauseKindSupport $cause_kind_support
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('causes.cause_kind_support.create');
    }

    /**
     * Determine if the given user can update the given cause_kind_support.
     *
     * @param UserPolicy $user
     * @param CauseKindSupport $cause_kind_support
     *
     * @return bool
     */
    public function update(UserPolicy $user, CauseKindSupport $cause_kind_support)
    {
        if ($user->canDo('causes.cause_kind_support.edit') && $user->isAdmin()) {
            return true;
        }

        return $cause_kind_support->user_id == user_id() && $cause_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cause_kind_support.
     *
     * @param UserPolicy $user
     * @param CauseKindSupport $cause_kind_support
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CauseKindSupport $cause_kind_support)
    {
        return $cause_kind_support->user_id == user_id() && $cause_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cause_kind_support.
     *
     * @param UserPolicy $user
     * @param CauseKindSupport $cause_kind_support
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CauseKindSupport $cause_kind_support)
    {
        if ($user->canDo('causes.cause_kind_support.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cause_kind_support.
     *
     * @param UserPolicy $user
     * @param CauseKindSupport $cause_kind_support
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CauseKindSupport $cause_kind_support)
    {
        if ($user->canDo('causes.cause_kind_support.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
