<?php

namespace Annie\Causes\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Causes\Models\Cause;

class CausePolicy
{

    /**
     * Determine if the given user can view the cause.
     *
     * @param UserPolicy $user
     * @param Cause $cause
     *
     * @return bool
     */
    public function view(UserPolicy $user, Cause $cause)
    {
        if ($user->canDo('causes.cause.view') && $user->isAdmin()) {
            return true;
        }

        return $cause->user_id == user_id() && $cause->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cause.
     *
     * @param UserPolicy $user
     * @param Cause $cause
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('causes.cause.create');
    }

    /**
     * Determine if the given user can update the given cause.
     *
     * @param UserPolicy $user
     * @param Cause $cause
     *
     * @return bool
     */
    public function update(UserPolicy $user, Cause $cause)
    {
        if ($user->canDo('causes.cause.edit') && $user->isAdmin()) {
            return true;
        }

        return $cause->user_id == user_id() && $cause->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cause.
     *
     * @param UserPolicy $user
     * @param Cause $cause
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Cause $cause)
    {
        return $cause->user_id == user_id() && $cause->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cause.
     *
     * @param UserPolicy $user
     * @param Cause $cause
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Cause $cause)
    {
        if ($user->canDo('causes.cause.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cause.
     *
     * @param UserPolicy $user
     * @param Cause $cause
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Cause $cause)
    {
        if ($user->canDo('causes.cause.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
