<?php

namespace Annie\Causes\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Causes\Models\CauseProject;

class CauseProjectPolicy
{

    /**
     * Determine if the given user can view the cause_project.
     *
     * @param UserPolicy $user
     * @param CauseProject $cause_project
     *
     * @return bool
     */
    public function view(UserPolicy $user, CauseProject $cause_project)
    {
        if ($user->canDo('causes.cause_project.view') && $user->isAdmin()) {
            return true;
        }

        return $cause_project->user_id == user_id() && $cause_project->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cause_project.
     *
     * @param UserPolicy $user
     * @param CauseProject $cause_project
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('causes.cause_project.create');
    }

    /**
     * Determine if the given user can update the given cause_project.
     *
     * @param UserPolicy $user
     * @param CauseProject $cause_project
     *
     * @return bool
     */
    public function update(UserPolicy $user, CauseProject $cause_project)
    {
        if ($user->canDo('causes.cause_project.edit') && $user->isAdmin()) {
            return true;
        }

        return $cause_project->user_id == user_id() && $cause_project->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cause_project.
     *
     * @param UserPolicy $user
     * @param CauseProject $cause_project
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CauseProject $cause_project)
    {
        return $cause_project->user_id == user_id() && $cause_project->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cause_project.
     *
     * @param UserPolicy $user
     * @param CauseProject $cause_project
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CauseProject $cause_project)
    {
        if ($user->canDo('causes.cause_project.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cause_project.
     *
     * @param UserPolicy $user
     * @param CauseProject $cause_project
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CauseProject $cause_project)
    {
        if ($user->canDo('causes.cause_project.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
