<?php

namespace Annie\Causes\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Annie\Causes\Models\Causes;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Annie\Causes\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/causes/cause/*')) {
            Route::bind('cause', function ($cause) {
                $causerepo = $this->app->make('Annie\Causes\Interfaces\CauseRepositoryInterface');
                return $causerepo->findorNew($cause);
            });
        }

        if (Request::is('*/causes/cause_kind_support/*')) {
            Route::bind('cause_kind_support', function ($cause_kind_support) {
                $cause_kind_supportrepo = $this->app->make('Annie\Causes\Interfaces\CauseKindSupportRepositoryInterface');
                return $cause_kind_supportrepo->findorNew($cause_kind_support);
            });
        }

        if (Request::is('*/causes/cause_project/*')) {
            Route::bind('cause_project', function ($cause_project) {
                $cause_projectrepo = $this->app->make('Annie\Causes\Interfaces\CauseProjectRepositoryInterface');
                return $cause_projectrepo->findorNew($cause_project);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        if(request()->segment(1) != 'api' && request()->segment(2) != 'api') {
            return;
        }

        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
